@@ -39,20 +39,21 @@ L<Data::Entropy>.
 
 package Data::Entropy::Algorithms;
 
+{ use 5.006; }
 use warnings;
 use strict;
 
 use Carp qw(croak);
 use Data::Entropy qw(entropy_source);
-use Data::Float 0.002 qw(
+use Data::Float 0.008 qw(
 	have_subnormal min_normal_exp significand_bits
 	float_is_finite float_parts float_sign mult_pow2 copysign
 );
 use Params::Classify 0.000 qw(is_ref);
 
-our $VERSION = "0.003";
+our $VERSION = "0.006";
 
-use base "Exporter";
+use parent "Exporter";
 our @EXPORT_OK = qw(
 	rand_bits rand_int rand_prob
 	rand_fix rand rand_flt
@@ -173,7 +174,7 @@ sub rand_fix($) {
 	return $frac;
 }
 
-=item rand[(LIMIT)]
+=item rand([LIMIT])
 
 Generates a random fixed-point fraction by C<rand_fix> and then multiplies
 it by LIMIT, returning the result.  LIMIT defaults to 1, and if it
@@ -193,8 +194,13 @@ changes, to maintain the match.
 Where the source of a module can't be readily modified, it can be made
 to use this C<rand> by an incantation such as
 
-	*Foreign::Module::rand =
-		\&Data::Entropy::Algorithms::rand;
+	*Foreign::Module::rand = \&Data::Entropy::Algorithms::rand;
+
+This must be done before the module is loaded, most likely in a C<BEGIN>
+block.  It is also possible to override C<CORE::rand> for all modules,
+by performing this similarly early:
+
+	*CORE::GLOBAL::rand = \&Data::Entropy::Algorithms::rand;
 
 This function should not be used in any new code, because the kind
 of output supplied by C<rand> is hardly ever the right thing to use.
@@ -428,7 +434,8 @@ sub shuffle(@) { @{shuffle_r(\@_)} }
 
 =head1 SEE ALSO
 
-L<Data::Entropy>
+L<Data::Entropy>,
+L<Data::Entropy::Source>
 
 =head1 AUTHOR
 
@@ -436,7 +443,9 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006, 2007 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2006, 2007, 2009 Andrew Main (Zefram) <zefram@fysh.org>
+
+=head1 LICENSE
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
